@@ -5,9 +5,12 @@ extern "C" {
 #endif
 
 void	init_auto_menu( void );
+void	init_auto_mark_all_appoint( void );
+void	init_auto_mark_appoint( long ls_mbr_n );
 void	init_auto_mark_all_mbr( void );
 void	init_auto_mark_mbr( long ls_mbr_n );
 void	ver_up_auto_mark_1_0_4( long ls_mbr_n );
+void	ver_up_auto_mark_1_1_1( long ls_mbr_n );
 char	*menu_auto_mark( menu_t **pp, menu_t **dflt );
 void	set_menu_auto_mark( menu_t **dflt );
 char	*cb_menu_auto_mark_exec( menu_t **pp, menu_t **dflt );
@@ -48,8 +51,13 @@ char	*cb_menu_auto_mark_appoint_item_init(
 char	*cb_menu_auto_mark_appoint_item_mnr(
 	menu_t **pp, menu_t **dflt
 );
+char	*cb_menu_auto_mark_macro( menu_t **pp, menu_t **dflt );
 char	*cb_menu_auto_mark_cont( menu_t **pp, menu_t **dflt );
 char	*cb_menu_auto_mark_priority( menu_t **pp, menu_t **dflt );
+char	*cb_menu_auto_mark_copy_large( menu_t **pp, menu_t **dflt );
+char	*cb_menu_auto_mark_paste_large( menu_t **pp, menu_t **dflt );
+char	*cb_menu_auto_mark_copy_small( menu_t **pp, menu_t **dflt );
+char	*cb_menu_auto_mark_paste_small( menu_t **pp, menu_t **dflt );
 char	*cb_menu_auto_mark_arrange( menu_t **pp, menu_t **dflt );
 char	*get_msg_menu_auto_mark_edit_trgt( mbr_t *mbr );
 char	*get_msg_menu_auto_mark_edit_dist( mbr_t *mbr );
