@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.53 2006/01/14 15:59:04 bowkenken Exp $
+* $Id: amenu.c,v 1.54 2006/02/01 15:30:18 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -1159,7 +1159,8 @@ char	*cb_menu_auto_mark_edit( menu_t **pp, menu_t **dflt )
 	auto_mark_cur_n = (long)((*pp)->arg);
 
 	while( 1 ){
-		str_goto = exec_menu_sel_mbr( &g_sel_mbr, NULL, TRUE, FALSE );
+		str_goto = exec_menu_sel_mbr(
+				&g_sel_mbr, NULL, TRUE, FALSE );
 		if( str_goto != NULL )
 			return str_goto;
 
