@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,13 +25,15 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.h,v 1.3 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: amenu.h,v 1.8 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	AMENU_H
 #define	AMENU_H
 
-/* ưޡ */
+/***************************************************************
+* ưޡ
+***************************************************************/
 
 /* ưޡκ */
 #define	AUTO_MARK_MAX_N	16
@@ -42,13 +44,20 @@
 /* ƥμκ */
 #define	AUTO_MARK_APPOINT_ITEM_MAX_N	64
 
-/* ޡ˺Ƥӥޡʤե饰 */
+/***************************************************************
+* ե饰
+* ֤Ѥϥ֡ǡ⽤
+***************************************************************/
+
+/* ޡ˺Ƥӥޡʤ */
 #define	FLG_AUTO_MARK_EDIT_CONT	(1 << 0)
 
-/* Ǥ˥ޡƤƤ⶯Ū˥ޡʤե饰 */
+/* Ǥ˥ޡƤƤ⶯Ū˥ޡʤ */
 #define	FLG_AUTO_MARK_EDIT_PRIORITY	(1 << 1)
 
-/* о */
+/***************************************************************
+* о
+***************************************************************/
 
 typedef enum {
 	AUTO_MARK_TRGT_MNSTR,
@@ -60,7 +69,9 @@ typedef enum {
 	AUTO_MARK_TRGT_CLEAR,
 } auto_mark_trgt_t;
 
-/* ֹ礤 */
+/***************************************************************
+* ֹ礤
+***************************************************************/
 
 typedef enum {
 	AUTO_MARK_DIST_NEAR,
@@ -68,7 +79,9 @@ typedef enum {
 	AUTO_MARK_DIST_FAR,
 } auto_mark_dist_t;
 
-/*  */
+/***************************************************************
+* 
+***************************************************************/
 
 typedef enum {
 	AUTO_MARK_ACT_FIGHT,
@@ -85,7 +98,9 @@ typedef enum {
 	AUTO_MARK_ACT_CHK,
 } auto_mark_act_t;
 
-/*  */
+/***************************************************************
+* 
+***************************************************************/
 
 typedef enum {
 	/* äȤᤤʪ */
@@ -101,13 +116,16 @@ typedef enum {
 	AUTO_MARK_COND_OWN,
 } auto_mark_cond_t;
 
-/**/
+/***************************************************************
+* ưޡ
+***************************************************************/
 
 typedef struct {
 	auto_mark_trgt_t	trgt;
 	auto_mark_dist_t	dist;
 	auto_mark_act_t	act;
 	auto_mark_cond_t	cond;
+	char	macro[MACRO_MAX_LEN + 1];
 	unsigned long	flg;
 } auto_mark_t;
 
