@@ -17,6 +17,11 @@ bool_t	chk_assist_chr( chr_t *chr );
 bool_t	chk_adjoin_chr_trgt( chr_t *chr );
 void	clr_map_chr( chr_t *chr );
 void	set_map_chr( chr_t *chr );
+void	clr_map_chr_dun( chr_t *chr );
+void	set_map_chr_dun( chr_t *chr );
+void	set_clr_map_chr_dun(
+	chr_t *chr, char mjr, char mnr, flg_map_t flg
+);
 void	move_chr( chr_t *chr );
 void	move_chr_sub( chr_t *chr );
 void	move_chr_std( chr_t *chr );
