@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,27 +25,33 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: chr.h,v 1.87 2004/12/13 14:14:23 bowkenken Exp $
+* $Id: chr.h,v 1.97 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CHR_H
 #define	CHR_H
 
-/* 饯 */
+/***************************************************************
+* 饯
+***************************************************************/
 
 #include	"dun.h"
 #include	"fight.h"
 #include	"fx.h"
+#include	"misc.h"
 
 #include	"resi.h"
 #include	"abl-kind.h"
 #include	"mnstr-kind.h"
 #include	"item-kind.h"
 
-/***************************************************************/
+/***************************************************************
+* иͤȥ٥
+***************************************************************/
 
-/*  */
-#define	ROLL_BASE	10
+/* иͤκ */
+#define	EXP_MAX	99999999
+#define	NEED_EXP_MAX	(EXP_MAX + 1)
 
 /* 饯Υ٥ȡµܤΥ٥ȤΨ */
 #define	RATE_LEV_PER_DUN_LEV	((rate_t)30)
@@ -61,6 +67,10 @@
 #define	RACE_STR_MAX_LEN	32	/* ݤ碌ޤ᤿²̾ */
 #define	RACE_NAME_MAX_LEN	16	/* ²̾ */
 
+/***************************************************************
+* 饯ǽ
+***************************************************************/
+
 #define	MOVE_LS_MAX_N	3	/* 饯ΰưμκ */
 
 #define	ABL_RATE_MIN_N	((rate_t)0)	/* иͤγ꿶κ */
@@ -115,14 +125,18 @@ typedef unsigned long	flg_stat_t;
 #define	FLG_STAT_VANISH	(1 << 18)	/* Ʃ */
 #define	FLG_STAT_IRON_BODY	(1 << 19)	/* Ŵ */
 #define	FLG_STAT_PASSWALL	(1 << 20)	/* ȴ */
+#define	FLG_STAT_SENSE_INVISIBLE	(1 << 21)	/* ԲĻ봶 */
 
-/***************************************************************/
+/***************************************************************
+* 饯Υե饰
+* ֤Ѥϥ֡ǡ⽤
+***************************************************************/
 
-/*  */
 typedef unsigned long	flg_work_t;
 
 /* 󥹥СȯƤ */
 #define	FLG_WORK_FIND_MBR	(1 << 0)
+
 /* 󥹥˥ƥǤ */
 #define	FLG_WORK_STEAL_END	(1 << 1)
 
@@ -140,11 +154,17 @@ typedef unsigned long	flg_work_t;
 #define	SQUARE_WIDTH	3	/*  */
 #define	SQUARE_HEIGHT	3	/* ⤵ */
 
+/***************************************************************
+* ¾
+***************************************************************/
+
+/*  */
+#define	ROLL_BASE	10
+
 /* κʸ */
 #define	ACT_MSG_MAX_LEN	64
 
 /* դĤΨ */
-
 #define	STAGGER_RATE_CHR_CONFUSION	((rate_t)70)	/*  */
 #define	STAGGER_RATE_CHR_BLIND	((rate_t)80)	/* ܤʤ */
 #define	STAGGER_RATE_CHR_DRUNK	((rate_t)50)	/* äƤ */
@@ -152,10 +172,9 @@ typedef unsigned long	flg_work_t;
 /* 󥹥λäƤ륢ƥκ */
 #define	MNSTR_ITEM_N_MAX_N	3
 
-/***************************************************************/
-
-/* 饯μ */
-/* ֤Ѥϥ֡ǡ⽤ */
+/***************************************************************
+* 饯μ
+***************************************************************/
 
 typedef enum {
 	CHR_KIND_NULL,
@@ -163,16 +182,19 @@ typedef enum {
 	CHR_KIND_MNSTR,	/* 󥹥 */
 } chr_kind_t;
 
-/* ̤ɽʸ() */
+/***************************************************************
+* ̤ɽʸ()
+***************************************************************/
 
 typedef struct {
 	char	mjr, mnr;
 	char	mjr_org, mnr_org;
 } chr_face_t;
 
-/* ² */
+/***************************************************************
+* ²
+***************************************************************/
 
-/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	MAIN_RACE_HUMAN,
 	MAIN_RACE_HALF_ELF,
@@ -182,7 +204,6 @@ typedef enum {
 	MAIN_RACE_MAX_N,
 } main_race_t;
 
-/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	SUB_RACE_NULL,
 	SUB_RACE_CAT,
@@ -202,9 +223,10 @@ typedef struct {
 	char	name[RACE_NAME_MAX_LEN + 1];
 } race_t;
 
-/*  */
+/***************************************************************
+* 
+***************************************************************/
 
-/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	SEX_NULL,
 
@@ -219,16 +241,19 @@ typedef struct {
 	sex_t	cur, org;
 } sex_dat_t;
 
-/* ư® */
+/***************************************************************
+* ư®
+***************************************************************/
 
 typedef struct {
 	rate_t	rate, rate_org;
 	long	n;
 } move_speed_t;
 
-/* ⤭ */
+/***************************************************************
+* ⤭μ
+***************************************************************/
 
-/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	MOVE_KIND_NULL,
 	MOVE_KIND_STOP,	/*  */
@@ -239,6 +264,10 @@ typedef enum {
 	MOVE_KIND_MAX_N,
 } move_kind_t;
 
+/***************************************************************
+* ⤭Υǡ
+***************************************************************/
+
 typedef struct {
 	/* ⤭ */
 	move_kind_t	kind;
@@ -247,6 +276,8 @@ typedef struct {
 	ratio_t	ratio;
 } move_ls_t;
 
+/* ⤭ǡμ */
+
 typedef enum {
 	/* Сȯ */
 	MOVE_LS_KIND_FIND,
@@ -263,6 +294,10 @@ typedef struct {
 	move_ls_t	ls[MOVE_LS_KIND_MAX_N][MOVE_LS_MAX_N];
 } move_t;
 
+/***************************************************************
+* ǽ
+***************************************************************/
+
 /* и */
 typedef struct {
 	long	n, max;
@@ -295,7 +330,10 @@ typedef struct {
 	long	mul_lev, add_lev;
 } lev_to_val_t;
 
-/* եѤΥ */
+/***************************************************************
+* եѤΥ
+***************************************************************/
+
 typedef struct fx_data {
 	/*  */
 	rate_t	wpn_hit, wpn_crtcl, wpn_dam;
@@ -321,7 +359,9 @@ typedef struct fx_data {
 	rate_t	bless;
 } fx_data_t;
 
-/* ˤ뽤 */
+/***************************************************************
+* ˤ뽤
+***************************************************************/
 
 typedef struct {
 	/*  */
@@ -367,7 +407,9 @@ typedef struct {
 #define	ADD_RESI_N_ALL_0	\
 	{ 0, 0, 0, 0, 0, 0, 0, 0, 0, },
 
-/* 饹() */
+/***************************************************************
+* ǥեȤΥ饹()
+***************************************************************/
 
 typedef enum {
 	CLASS_DFLT_NULL,
@@ -384,6 +426,10 @@ typedef enum {
 	CLASS_DFLT_BISHOP,
 } class_dflt_t;
 
+/***************************************************************
+* 饹()
+***************************************************************/
+
 typedef struct {
 	/* ̾ */
 	n_msg_t	n_name;
@@ -395,9 +441,10 @@ typedef struct {
 	rate_t	abl_rate[ABL_KIND_MAX_N];
 } class_t;
 
-/*  */
+/***************************************************************
+* 
+***************************************************************/
 
-/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	ACT_KIND_NULL,
 	ACT_KIND_MNSTR_FIGHT,
@@ -463,9 +510,12 @@ typedef struct {
 	char	dflt_msg_mnstr[ACT_MSG_MAX_LEN + 1];
 } act_t;
 
-/* å */
+/***************************************************************
+* å
+***************************************************************/
+
+/* åȤμ */
 
-/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
 	TRGT_KIND_NULL,
 	TRGT_KIND_MBR,
@@ -483,11 +533,13 @@ typedef enum {
 
 /* ֹ礤 */
 
-/* ֤Ѥϥ֡ǡ⽤ */
 typedef enum {
-	DIST_NEAR,	/* ᤯ */
-	DIST_MEDIUM,	/*  */
-	DIST_FAR,	/*  */
+	/* ᤯ */
+	DIST_NEAR,
+	/*  */
+	DIST_MEDIUM,
+	/*  */
+	DIST_FAR,
 } dist_t;
 
 /* ɸ */
@@ -509,7 +561,9 @@ typedef struct {
 	dist_t	dist, dflt_dist_mnstr;
 } trgt_t;
 
-/* ١ȿ */
+/***************************************************************
+* ١ȿ
+***************************************************************/
 
 typedef enum {
 	/*  */
@@ -522,7 +576,9 @@ typedef enum {
 	ATTITUDE_ENEMY,
 } attitude_t;
 
-/*  */
+/***************************************************************
+* 
+***************************************************************/
 
 typedef struct {
 	/* ե饰 */
@@ -552,7 +608,9 @@ typedef struct {
 	long	dismissal_turn;
 } chr_work_t;
 
-/* 󥹥ƥ */
+/***************************************************************
+* 󥹥ƥ
+***************************************************************/
 
 typedef struct {
 	/*  */
@@ -566,7 +624,9 @@ typedef struct {
 	long	k1, k2, k3;
 } mnstr_item_n_t;
 
-/* 󥹥Υǡơ֥ */
+/***************************************************************
+* 󥹥Υǡơ֥
+***************************************************************/
 
 typedef struct {
 	/* 󥹥μ */
@@ -597,6 +657,9 @@ typedef struct {
 	/* ݤȤࡦƥο */
 	long	item_max_n;
 
+	/* ݤȤ(ƥ)ο */
+	long	bone_ave_n;
+
 	/* ݤȤꥢƥ */
 	mnstr_item_n_t	item_n[MNSTR_ITEM_N_MAX_N + 1];
 
@@ -631,7 +694,9 @@ typedef struct {
 	flg_stat_t	resi_stat;
 } mnstr_tab_t;
 
-/* 饯(PC,NPC,󥹥) */
+/***************************************************************
+* 饯(PC,NPC,󥹥)
+***************************************************************/
 
 typedef struct chr_t {
 	/* ꥹȤ */
