@@ -39,6 +39,8 @@ void	wipe_all( void );
 void	redraw_all( void );
 void	draw_map( long map_x, long map_y, long dx, long dy );
 void	redraw_map( void );
+void	wipe_map( void );
+void	force_redraw_map( void );
 void	draw_chr( chr_t *chr );
 void	draw_party( void );
 void	draw_mbr( mbr_t *p );
@@ -66,6 +68,7 @@ bool_t	vfx_spell_conflagration_sub( long x, long y, long height );
 void	vfx_spell_earthquake( void );
 void	vfx_spell_thunder( long arw_n, pos_t end[] );
 void	vfx_spell_inundation( void );
+void	vfx_hit( chr_kind_t kind, long x, long y );
 void	vfx_crtcl( chr_kind_t kind, long x, long y );
 void	vfx_ninja_crtcl( chr_kind_t kind, long x, long y );
 void	get_vfx_attr( curs_attr_t *attr );
@@ -113,6 +116,7 @@ bool_t	game_gets( long x, long y, char *s, long len, bool_t flg_pick );
 void	pick_cntrl_str( char *s );
 void	set_crsr( long x, long y );
 void	reset_crsr( void );
+void	draw_crsr( void );
 void	draw_sub_crsr( void );
 pos_t	*get_map_draw_pos( void );
 rate_t	get_vfx_wait( void );
@@ -122,6 +126,8 @@ flg_vfx_mbr_t	set_flg_vfx_mbr( flg_vfx_mbr_t flg );
 flg_vfx_mnstr_t	get_flg_vfx_mnstr( void );
 flg_vfx_mnstr_t	set_flg_vfx_mnstr( flg_vfx_mnstr_t flg );
 void	wait_clock( long frame );
+void	set_flg_break_key( bool_t flg_break );
+bool_t	chk_flg_break_key( void );
 long	read_char( long *p );
 long	read_char_wait( long *p );
 long	read_esc( long *p );
