@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw-tab.h,v 1.9 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: draw-tab.h,v 1.11 2006/02/17 05:52:47 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_TAB_H
@@ -251,20 +251,25 @@
 		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 9)
 
 #define	WIN_MBR_DATA_STAT_IRON_BODY_DRAW_MIN_X	\
-		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 0)
+		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 20)
 #define	WIN_MBR_DATA_STAT_IRON_BODY_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 9)
 
 #define	WIN_MBR_DATA_STAT_PASSWALL_DRAW_MIN_X	\
-		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 20)
+		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 0)
 #define	WIN_MBR_DATA_STAT_PASSWALL_DRAW_MIN_Y	\
-		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 9)
+		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 10)
 
 #define	WIN_MBR_DATA_STAT_SENSE_INVISIBLE_DRAW_MIN_X	\
-		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 0)
+		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 20)
 #define	WIN_MBR_DATA_STAT_SENSE_INVISIBLE_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 10)
 
+#define	WIN_MBR_DATA_STORE_LIGHT_DRAW_MIN_X	\
+		(WIN_MBR_DATA_STAT_DRAW_MIN_X + 0)
+#define	WIN_MBR_DATA_STORE_LIGHT_DRAW_MIN_Y	\
+		(WIN_MBR_DATA_STAT_DRAW_MIN_Y + 11 + 1)
+
 /* page 2/2 */
 
 #define	WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_X	(0 + 4)
@@ -540,6 +545,8 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_STAT_PASSWALL, */
 		FALSE,	/* DATA_N_STAT_SENSE_INVISIBLE, */
 
+		FALSE,	/* DATA_N_STORE_LIGHT, */
+
 		FALSE,	/* DATA_N_LEV_LEFT, */
 		FALSE,	/* DATA_N_EXP_LEFT, */
 		FALSE,	/* DATA_N_NEED_EXP_LEFT, */
@@ -638,6 +645,8 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_STAT_PASSWALL, */
 		FALSE,	/* DATA_N_STAT_SENSE_INVISIBLE, */
 
+		FALSE,	/* DATA_N_STORE_LIGHT, */
+
 		FALSE,	/* DATA_N_LEV_LEFT, */
 		FALSE,	/* DATA_N_EXP_LEFT, */
 		FALSE,	/* DATA_N_NEED_EXP_LEFT, */
@@ -736,6 +745,8 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_STAT_PASSWALL, */
 		FALSE,	/* DATA_N_STAT_SENSE_INVISIBLE, */
 
+		FALSE,	/* DATA_N_STORE_LIGHT, */
+
 		FALSE,	/* DATA_N_LEV_LEFT, */
 		FALSE,	/* DATA_N_EXP_LEFT, */
 		FALSE,	/* DATA_N_NEED_EXP_LEFT, */
@@ -837,6 +848,8 @@ long	data_page_n_tab[] = {
 	0,	/* DATA_N_STAT_PASSWALL, */
 	0,	/* DATA_N_STAT_SENSE_INVISIBLE, */
 
+	0,	/* DATA_N_STORE_LIGHT, */
+
 	1,	/* DATA_N_LEV_LEFT, */
 	1,	/* DATA_N_EXP_LEFT, */
 	1,	/* DATA_N_NEED_EXP_LEFT, */
