@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.113 2006/01/15 01:11:03 bowkenken Exp $
+* $Id: fight.c,v 1.115 2006/01/27 16:25:25 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -842,6 +842,8 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 	if( (d_p != NULL) && chk_map_sanctuary( d_p->x, d_p->y ) )
 		return FALSE;
 
+	/* ꤲʪ̵ʤä饭󥻥 */
+
 	eq = NULL;
 	if( attack->flg_throw && (o_k == CHR_KIND_MBR) ){
 		eq = get_mbr_item_asgn_equip( (mbr_t *)o_p );
@@ -870,6 +872,11 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 		return FALSE;
 	}
 
+	/* Ʃθ̤ */
+
+	if( cancel_fx_vanish( o_p ) )
+		return FALSE;
+
 	/* ø */
 
 	flg_serious = TRUE;
@@ -1243,6 +1250,11 @@ bool_t	spell_attack(
 		return FALSE;
 	}
 
+	/* Ʃθ̤ */
+
+	if( cancel_fx_vanish( o_p ) )
+		return FALSE;
+
 	/* ø */
 
 	flg_serious = TRUE;
