@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile-tab.h,v 1.13 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: gfile-tab.h,v 1.14 2006/02/17 04:45:36 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_TAB_H
@@ -1407,6 +1407,7 @@ spell_kind_t	g_spell_trans_tab[] = {
 /* ɲ */
 	SPELL_KIND_IDENTIFY_ALL_ITEM,
 	SPELL_KIND_SUMMON_BONE,
+	SPELL_KIND_STORE_LIGHT,
 };
 
 /***************************************************************
@@ -1670,6 +1671,7 @@ fx_kind_t	g_fx_trans_tab[] = {
 	FX_KIND_SPEED_UP,
 	FX_KIND_SPEED_DOWN,
 	FX_KIND_BLESS,
+	FX_KIND_STORE_LIGHT,
 };
 
 /***************************************************************
