@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.69 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: gmain.c,v 1.72 2006/02/01 18:35:37 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -74,6 +74,8 @@ void	init_game( void )
 {
 	dun_t	*dun;
 
+	g_flg_init = FALSE;
+
 	init_signal();
 	init_scrn();
 
@@ -90,6 +92,9 @@ void	init_game( void )
 	init_game_file();
 
 	init_var_menu();
+	init_var_main_menu();
+	init_var_misc_menu();
+
 	if( !load_game_conf() )
 		g_flg_measure_clk_tck = TRUE;
 
@@ -103,6 +108,8 @@ void	init_game( void )
 	init_menu();
 	init_tmenu();
 	init_auto_menu();
+	init_misc_menu();
+	init_main_menu();
 	init_request();
 
 	init_mbr_formation();
@@ -117,6 +124,8 @@ void	init_game( void )
 	dun = get_dun();
 	dun->lev = 0;
 	up_dun( 0 );
+
+	g_flg_init = TRUE;
 }
 
 /***************************************************************
