@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: inc.h,v 1.8 2006/01/15 16:34:45 bowkenken Exp $
+* $Id: inc.h,v 1.11 2006/02/15 00:33:03 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	INC_H
@@ -76,6 +76,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
+#include	"mmenu-prot.h"
+#include	"imenu-prot.h"
 /*#include	"tmenu-prot.h"*/
 #include	"amenu-prot.h"
 /*#include	"request-prot.h"*/
@@ -127,6 +129,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 #include	"amenu-prot.h"
 #include	"request-prot.h"
@@ -178,6 +182,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -241,6 +247,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
+#include	"mmenu-prot.h"
+/*#include	"imenu-prot.h"*/
 #include	"tmenu-prot.h"
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -304,6 +312,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
+#include	"mmenu-prot.h"
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 #include	"request-prot.h"
@@ -360,6 +370,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -411,6 +423,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
+#include	"mmenu-prot.h"
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -461,6 +475,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
+#include	"mmenu-prot.h"
+#include	"imenu-prot.h"
 /*#include	"tmenu-prot.h"*/
 #include	"amenu-prot.h"
 #include	"request-prot.h"
@@ -511,6 +527,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
+#include	"mmenu-prot.h"
+#include	"imenu-prot.h"
 #include	"tmenu-prot.h"
 #include	"amenu-prot.h"
 #include	"request-prot.h"
@@ -527,6 +545,61 @@
 
 /***************************************************************/
 
+#ifdef	IMENU_C
+
+#include	"gmain.h"
+#include	"misc.h"
+#include	"turn.h"
+#include	"dun.h"
+#include	"town.h"
+#include	"item.h"
+/*#include	"spell.h"*/
+#include	"chr.h"
+#include	"party.h"
+#include	"mnstr.h"
+#include	"pet.h"
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+#include	"trap.h"
+#include	"draw.h"
+#include	"curs.h"
+#include	"menu.h"
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+#include	"gfile.h"
+#include	"msg.h"
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+#include	"misc-prot.h"
+#include	"turn-prot.h"
+#include	"dun-prot.h"
+#include	"town-prot.h"
+#include	"item-prot.h"
+/*#include	"spell-prot.h"*/
+#include	"chr-prot.h"
+#include	"party-prot.h"
+#include	"mnstr-prot.h"
+#include	"pet-prot.h"
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+#include	"trap-prot.h"
+#include	"draw-prot.h"
+#include	"curs-prot.h"
+#include	"menu-prot.h"
+#include	"mmenu-prot.h"
+#include	"imenu-prot.h"
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+#include	"gfile-prot.h"
+#include	"msg-prot.h"
+
+#include	"call-prot.h"
+
+#endif	/* IMENU_C */
+
+/***************************************************************/
+
 #ifdef	ITEM_C
 
 #include	"gmain.h"
@@ -568,6 +641,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 #include	"amenu-prot.h"
 #include	"request-prot.h"
@@ -620,6 +695,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -678,6 +755,8 @@
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -703,14 +782,14 @@
 #ifdef	MENU_C
 
 #include	"gmain.h"
-/*#include	"misc.h"*/
-#include	"turn.h"
+#include	"misc.h"
+/*#include	"turn.h"*/
 /*#include	"dun.h"*/
-#include	"town.h"
+/*#include	"town.h"*/
 /*#include	"item.h"*/
-#include	"spell.h"
+/*#include	"spell.h"*/
 /*#include	"chr.h"*/
-/*#include	"party.h"*/
+#include	"party.h"
 /*#include	"mnstr.h"*/
 #include	"pet.h"
 /*#include	"fight.h"*/
@@ -721,31 +800,33 @@
 #include	"menu.h"
 /*#include	"amenu.h"*/
 /*#include	"request.h"*/
-#include	"gfile.h"
+/*#include	"gfile.h"*/
 #include	"msg.h"
 /*#include	"ver.h"*/
-#include	"gmain-prot.h"
+/*#include	"gmain-prot.h"*/
 #include	"misc-prot.h"
-#include	"turn-prot.h"
-#include	"dun-prot.h"
-#include	"town-prot.h"
-#include	"item-prot.h"
-#include	"spell-prot.h"
-#include	"chr-prot.h"
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
 #include	"party-prot.h"
-#include	"mnstr-prot.h"
+/*#include	"mnstr-prot.h"*/
 #include	"pet-prot.h"
 /*#include	"fight-prot.h"*/
-#include	"fx-prot.h"
-#include	"trap-prot.h"
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
 #include	"draw-prot.h"
-#include	"curs-prot.h"
+/*#include	"curs-prot.h"*/
 #include	"menu-prot.h"
+#include	"mmenu-prot.h"
+#include	"imenu-prot.h"
 /*#include	"tmenu-prot.h"*/
-#include	"amenu-prot.h"
+/*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
-#include	"gfile-prot.h"
-#include	"msg-prot.h"
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
 
 #include	"call-prot.h"
 
@@ -794,6 +875,8 @@
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -804,6 +887,61 @@
 
 /***************************************************************/
 
+#ifdef	MMENU_C
+
+#include	"gmain.h"
+/*#include	"misc.h"*/
+#include	"turn.h"
+/*#include	"dun.h"*/
+#include	"town.h"
+/*#include	"item.h"*/
+#include	"spell.h"
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+#include	"pet.h"
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+#include	"menu.h"
+#include	"amenu.h"
+/*#include	"request.h"*/
+#include	"gfile.h"
+#include	"msg.h"
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+#include	"misc-prot.h"
+#include	"turn-prot.h"
+#include	"dun-prot.h"
+#include	"town-prot.h"
+#include	"item-prot.h"
+#include	"spell-prot.h"
+#include	"chr-prot.h"
+#include	"party-prot.h"
+#include	"mnstr-prot.h"
+#include	"pet-prot.h"
+/*#include	"fight-prot.h"*/
+#include	"fx-prot.h"
+#include	"trap-prot.h"
+#include	"draw-prot.h"
+#include	"curs-prot.h"
+#include	"menu-prot.h"
+#include	"mmenu-prot.h"
+#include	"imenu-prot.h"
+#include	"tmenu-prot.h"
+#include	"amenu-prot.h"
+/*#include	"request-prot.h"*/
+#include	"gfile-prot.h"
+#include	"msg-prot.h"
+
+#include	"call-prot.h"
+
+#endif	/* MMENU_C */
+
+/***************************************************************/
+
 #ifdef	MNSTR_ACT_C
 
 #include	"gmain.h"
@@ -846,6 +984,8 @@
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 #include	"request-prot.h"
@@ -897,6 +1037,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -948,6 +1090,8 @@
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -999,6 +1143,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
+/*#include	"mmenu-prot.h"*/
+#include	"imenu-prot.h"
 /*#include	"tmenu-prot.h"*/
 #include	"amenu-prot.h"
 /*#include	"request-prot.h"*/
@@ -1051,6 +1197,8 @@
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -1102,6 +1250,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
+/*#include	"mmenu-prot.h"*/
+#include	"imenu-prot.h"
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 #include	"request-prot.h"
@@ -1153,6 +1303,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
+#include	"mmenu-prot.h"
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -1204,6 +1356,8 @@
 #include	"draw-prot.h"
 #include	"curs-prot.h"
 #include	"menu-prot.h"
+#include	"mmenu-prot.h"
+#include	"imenu-prot.h"
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -1255,6 +1409,8 @@
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 #include	"menu-prot.h"
+#include	"mmenu-prot.h"
+#include	"imenu-prot.h"
 #include	"tmenu-prot.h"
 /*#include	"amenu-prot.h"*/
 #include	"request-prot.h"
@@ -1306,6 +1462,8 @@
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 #include	"menu-prot.h"
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -1357,6 +1515,8 @@
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 #include	"request-prot.h"
@@ -1410,6 +1570,8 @@
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -1474,6 +1636,8 @@
 #include	"draw-prot.h"
 /*#include	"curs-prot.h"*/
 /*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
 /*#include	"tmenu-prot.h"*/
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
