@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,87 +25,38 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-dos.c,v 1.2 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: main-dos.c,v 1.8 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-/*#include	"misc.h"*/
-/*#include	"turn.h"*/
-/*#include	"misc.h"*/
-/*#include	"dun.h"*/
-/*#include	"town.h"*/
-/*#include	"item.h"*/
-/*#include	"spell.h"*/
-/*#include	"chr.h"*/
-/*#include	"party.h"*/
-/*#include	"mnstr.h"*/
-/*#include	"pet.h"*/
-/*#include	"fight.h"*/
-/*#include	"fx.h"*/
-/*#include	"trap.h"*/
-#include	"draw.h"
-#include	"curs.h"
-/*#include	"menu.h"*/
-/*#include	"amenu.h"*/
-/*#include	"request.h"*/
-/*#include	"gfile.h"*/
-#include	"msg.h"
-#include	"ver.h"
-#include	"gmain-prot.h"
-/*#include	"misc-prot.h"*/
-/*#include	"turn-prot.h"*/
-/*#include	"dun-prot.h"*/
-/*#include	"town-prot.h"*/
-/*#include	"item-prot.h"*/
-/*#include	"spell-prot.h"*/
-/*#include	"chr-prot.h"*/
-/*#include	"party-prot.h"*/
-/*#include	"mnstr-prot.h"*/
-/*#include	"pet-prot.h"*/
-/*#include	"fight-prot.h"*/
-/*#include	"fx-prot.h"*/
-/*#include	"trap-prot.h"*/
-#include	"draw-prot.h"
-#include	"curs-prot.h"
-/*#include	"menu-prot.h"*/
-/*#include	"tmenu-prot.h"*/
-/*#include	"amenu-prot.h"*/
-/*#include	"request-prot.h"*/
-/*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
+/***************************************************************
+* DOS ѤΥᥤ
+***************************************************************/
 
-#include	"main-dos-prot.h"
+#define	MAIN_DOS_C
+#include	"inc.h"
 
-/**/
-
-#if	HAVE_GETOPT_H
-# include	<getopt.h>
-#endif	/* HAVE_GETOPT_H */
-
-#if	HAVE_TERMIOS_H
-# include	<termios.h>
-#elif	HAVE_TERMIO_H
-# include	<termio.h>
-#endif
-
-#if	HAVE_TERMIOS_H
-struct termios	pre_tbuf;
-#elif	HAVE_TERMIO_H
-struct termio	pre_tbuf;
-#endif
-
-/**/
+/***************************************************************
+* 
+***************************************************************/
 
 #define	STR_ENV_SHELL	"SHELL"
 #ifdef	D_DOS
-#define	STR_DFLT_SHELL	"command"
+# define	STR_DFLT_SHELL	"command"
 #else	/* D_DOS */
-#define	STR_DFLT_SHELL	"sh"
+# define	STR_DFLT_SHELL	"sh"
 #endif	/* D_DOS */
 
+/***************************************************************
+* Ԥ
+***************************************************************/
+
 #define	KEY_WAIT_VMIN	0
 #define	KEY_WAIT_VTIME	1
 
+/***************************************************************
+* 
+***************************************************************/
+
 #define	OPT_ARG_MAX_LEN	128
 #define	STR_OPT	"c:p:e:m:Vh"
 
@@ -119,7 +70,11 @@ static struct option	long_opt[] = {
 	{ "help",          no_argument,       NULL, 'h' },
 	{ 0, 0, 0, 0 }
 };
-#endif	/* HAVE_GETOPT */
+#endif	/* HAVE_GETOPT_LONG */
+
+/***************************************************************
+* 
+***************************************************************/
 
 #define	STR_USAGE	\
 	"Usage: %s [OPTION]...\n" \
@@ -135,11 +90,18 @@ static struct option	long_opt[] = {
 	"  -V, --version            display version and exit\n" \
 	"  -h, --help               display this help and exit\n"
 
-/**/
+/***************************************************************
+* ѿ
+***************************************************************/
 
 long	flg_term;
 
-/**/
+/***************************************************************
+* ᥤ󡦥롼
+* int argc : ο
+* char **argv : Υꥹ
+* return : λ
+***************************************************************/
 
 int	main_dos( void )
 {
@@ -151,7 +113,11 @@ int	main_dos( void )
 	return EXIT_FAILURE;
 }
 
-/**/
+/***************************************************************
+* ν
+* int argc : ο
+* char **argv : Υꥹ
+***************************************************************/
 
 void	chk_arg( int argc, char **argv )
 {
@@ -171,6 +137,7 @@ void	chk_arg( int argc, char **argv )
 		switch( c ){
 		case 'c':
 			g_flg_clr_key_buf = chk_opt_flg( optarg );
+			g_flg_clr_key_buf_menu = g_flg_clr_key_buf;
 			break;
 		case 'p':
 			g_flg_use_keypad = chk_opt_flg( optarg );
@@ -207,7 +174,11 @@ void	chk_arg( int argc, char **argv )
 #endif	/* HAVE_GETOPT || HAVE_GETOPT_LONG */
 }
 
-/**/
+/***************************************************************
+* Υ󡿥դΥե饰å
+* const char *optarg : ץʸ
+* return : ե饰?
+***************************************************************/
 
 bool_t	chk_opt_flg( const char *optarg )
 {
@@ -249,20 +220,31 @@ bool_t	chk_opt_flg( const char *optarg )
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* ɽ
+* FILE *fp : ե
+***************************************************************/
 
 void	usage( FILE *fp )
 {
+	if( !g_flg_cui )
+		return;
+
 	fprintf( fp, STR_USAGE, STR_FILE_NAME_GAME );
 	fflush( fp );
 }
 
-/**/
+/***************************************************************
+* θƤӽФ
+***************************************************************/
 
 void	child_ps_dos( void )
 {
 	char	*shell;
 
+	if( !g_flg_cui )
+		return;
+
 	dis_scrn();
 
 	shell = getenv( STR_ENV_SHELL );
@@ -276,56 +258,75 @@ void	child_ps_dos( void )
 	ena_scrn( FALSE );
 }
 
-/**/
+/***************************************************************
+* üν
+***************************************************************/
 
 void	init_term_dos( void )
 {
 	flg_term = 0;
 }
 
-/**/
+/***************************************************************
+* üͭĴ٤
+* return : üͭ?
+***************************************************************/
 
 bool_t	chk_term_dos( void )
 {
 	return( flg_term > 0 );
 }
 
-/**/
+/***************************************************************
+* üͭˤ
+***************************************************************/
 
 void	ena_term_dos( void )
 {
+	if( !g_flg_cui )
+		return;
+
 	flg_term++;
 }
 
-/**/
+/***************************************************************
+* ü̵ˤ
+***************************************************************/
 
 void	dis_term_dos( void )
 {
-	if( flg_term == 1 ){
-	}
+	if( !g_flg_cui )
+		return;
 
 	flg_term--;
 }
 
-/**/
+/***************************************************************
+* Ԥ
+***************************************************************/
 
 void	set_key_wait_dos( void )
 {
 	set_key_wait_vtime( KEY_WAIT_VTIME );
 }
 
-/**/
+/***************************************************************
+* Ԥ
+***************************************************************/
 
 void	clr_key_wait_dos( void )
 {
 	set_key_wait_vtime( 0 );
 }
 
-/**/
+/***************************************************************
+* Ԥ֤
+* long wait_vtime : Ԥ
+***************************************************************/
 
 void	set_key_wait_vtime( long wait_vtime )
 {
+	if( !g_flg_cui )
+		return;
 }
 
-/**/
-
