@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.h,v 1.26 2004/12/06 07:00:15 bowkenken Exp $
+* $Id: menu.h,v 1.32 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MENU_H
@@ -33,14 +33,14 @@
 
 /* ˥塼 */
 
-#include	"party.h"
 #include	"item.h"
+#include	"party.h"
 #include	"msg.h"
 
 /*  */
 
 #define	STR_MENU_ERR	"# Error"
-#define	STR_MENU_CANCEL	"# Cancel"
+#define	STR_MENU_CANCEL	".."
 
 /* ˥塼ѤΥ */
 
@@ -102,8 +102,11 @@
 /* ܤμκʸ */
 #define	MENU_KIND_MAX_LEN	16
 
-/* 졼κʸ */
-#define	MENU_ACCEL_KEY_MAX_LEN	16
+/* ޥκʸ */
+#define	MACRO_MAX_LEN	64
+
+/* 硼ȡåȡκʸ */
+#define	MENU_SHORT_KEY_MAX_LEN	16
 
 /* ܤκʸ */
 #define	MENU_MSG_MAX_LEN	128
@@ -138,10 +141,10 @@ typedef struct menu_t {
 	/* ܤμ */
 	char	kind[MENU_KIND_MAX_LEN + 1];
 
-	/* ľΥ */
-	unsigned char	key;
+	/* 졼 */
+	unsigned char	accel_key;
 	/* 硼ȡåȡ */
-	char	accel_key[MENU_ACCEL_KEY_MAX_LEN + 1];
+	char	short_key[MENU_SHORT_KEY_MAX_LEN + 1];
 
 	/* ̾ */
 	n_msg_t	n_msg;
