@@ -4,6 +4,8 @@
 extern "C" {
 #endif
 
+char	*fmt_gold( gold_t gold );
+char	*fmt_num( long n );
 long	sgn_l( long n );
 long	min_l( long n1, long n2 );
 long	max_l( long n1, long n2 );
@@ -20,7 +22,7 @@ long	str_len_draw_english( const char *s );
 long	str_len_draw_japanese_euc( const char *s );
 long	str_len_draw_japanese_utf_8( const char *s );
 long	str_len_std( const char *s );
-char	*str_max_n_cat( char *dst, char *src, int len );
+char	*str_max_n_cat( char *dst, const char *src, int len );
 bool_t	chk_flg( unsigned long var, unsigned long flg );
 bool_t	chk_flg_or( unsigned long var, unsigned long flg );
 void	*alloc_mem( long size, bool_t flg_exit );
