@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,77 +25,56 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr-act.c,v 1.6 2004/12/23 07:24:08 bowkenken Exp $
+* $Id: mnstr-act.c,v 1.12 2006/01/15 13:33:45 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-#include	"misc.h"
-#include	"turn.h"
-#include	"dun.h"
-#include	"town.h"
-#include	"item.h"
-/*#include	"spell.h"*/
-#include	"chr.h"
-#include	"party.h"
-#include	"mnstr.h"
-#include	"pet.h"
-/*#include	"fight.h"*/
-#include	"fx.h"
-/*#include	"trap.h"*/
-#include	"draw.h"
-/*#include	"curs.h"*/
-/*#include	"menu.h"*/
-/*#include	"amenu.h"*/
-#include	"request.h"
-/*#include	"gfile.h"*/
-/*#include	"msg.h"*/
-/*#include	"ver.h"*/
-/*#include	"gmain-prot.h"*/
-#include	"misc-prot.h"
-#include	"turn-prot.h"
-#include	"dun-prot.h"
-#include	"town-prot.h"
-#include	"item-prot.h"
-/*#include	"spell-prot.h"*/
-#include	"chr-prot.h"
-#include	"party-prot.h"
-#include	"mnstr-prot.h"
-#include	"mnstr-act-prot.h"
-#include	"pet-prot.h"
-/*#include	"fight-prot.h"*/
-#include	"fx-prot.h"
-/*#include	"trap-prot.h"*/
-#include	"draw-prot.h"
-/*#include	"curs-prot.h"*/
-/*#include	"menu-prot.h"*/
-/*#include	"tmenu-prot.h"*/
-/*#include	"amenu-prot.h"*/
-#include	"request-prot.h"
-/*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
+/***************************************************************
+* 󥹥Υ
+***************************************************************/
 
-/**/
+#define	MNSTR_ACT_C
+#include	"inc.h"
 
+/***************************************************************/
+
+/* 󥹥ۤγ */
 #define	PICK_GOLD_RATE	((rate_t)10)
+/* 󥹥ۤκ */
 #define	PICK_GOLD_MAX_N	((gold_t)500)
 
+/* 󥹥 */
 #define	INCREASE_RATE_GIANT_RAT	20
 
+/* ν̱ɥΨ西 */
 #define	TOWNER_ENTER_DOOR_RATE	10
+/* ν̱ɥΥ */
 #define	TOWNER_ENTER_DOOR_R	3
+/* ν̱ɥΤΨ西 */
 #define	TOWNER_CANCEL_DOOR_RATE	10
 
+/* ν̱ɥФΨΣܡ西 */
 #define	TOWNER_EXIT_DOOR_RATE	((rate_t)2)
+/* ν̱ɥФΨΣܡ */
 #define	TOWNER_EXIT_DOOR_RATE_DAY	((rate_t)100)
+/* ν̱ɥФΨΣܡ */
 #define	TOWNER_EXIT_DOOR_RATE_NIGHT	((rate_t)1)
 
-/*  */
+/***************************************************************
+* ƥ󥹥ζ̤Υ
+***************************************************************/
+
+/***************************************************************
+* ̤Υ
+* mnstr_t *p : 󥹥
+***************************************************************/
 
 void	set_act_mnstr_std( mnstr_t *p )
 {
 	if( p == NULL )
 		return;
 
+	/* ȤξΥ */
+
 	if( p->attitude == ATTITUDE_MATE ){
 		set_act_pet_std( p );
 		return;
@@ -105,17 +84,25 @@ void	set_act_mnstr_std( mnstr_t *p )
 
 	mnstr_mark_mbr_std( p );
 
+	/* СȯƤϹ⤹ */
+
 	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
 		mnstr_move_or_atack_std( p );
 }
 
-/**/
+/***************************************************************
+* Хȥ󥭥Хζ̤Υ
+* mnstr_t *p : 󥹥
+* sex_t sex : դ饯
+***************************************************************/
 
 void	set_act_mnstr_cubus( mnstr_t *p, sex_t sex )
 {
 	if( p == NULL )
 		return;
 
+	/* ȤξΥ */
+
 	if( p->attitude == ATTITUDE_MATE ){
 		set_act_pet_std( p );
 		return;
@@ -123,11 +110,18 @@ void	set_act_mnstr_cubus( mnstr_t *p, sex_t sex )
 
 	mnstr_mark_mbr_cubus( p, sex );
 
+	/* СȯƤϹ⤹ */
+
 	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
 		mnstr_move_or_atack_std( p );
 }
 
-/**/
+/***************************************************************
+* ѿȤ󥹥ζ̤Υ
+* mnstr_t *p : 󥹥
+* mnstr_kind_t kind : ѿȤ󥹥
+* rate_t rate : ѿȤΨ
+***************************************************************/
 
 void	set_act_mnstr_metamorphose(
 	mnstr_t *p, mnstr_kind_t kind, rate_t rate
@@ -141,17 +135,22 @@ void	set_act_mnstr_metamorphose(
 		return;
 
 	meta_tab = get_mnstr_tab( kind, 0 );
-	tab = NULL;
 
+	tab = NULL;
 	if( rate_randm( rate ) ){
-		if( p->face.mjr == p->mnstr_tab->face_mjr ){
+		if( (p->face.mjr == p->mnstr_tab->face_mjr)
+				&& (p->face.mnr == p->mnstr_tab->face_mnr) ){
+			/* ѿȤ */
 			tab = meta_tab;
 		} else {
+			/*  */
 			tab = p->mnstr_tab;
 		}
 	}
 
 	if( tab != NULL ){
+		/* ѿȤ뤫 */
+
 		p->move = tab->move;
 		p->modifier_fx.face_mjr = tab->face_mjr;
 		p->modifier_fx.face_mnr = tab->face_mnr;
@@ -160,27 +159,43 @@ void	set_act_mnstr_metamorphose(
 	if( p->face.mjr == p->mnstr_tab->face_mjr ){
 		set_act_mnstr_std( p );
 	} else {
+		/* ѿȸΥ */
+
 		meta_tab->func( p );
 	}
 }
 
+/***************************************************************
+* ν̱ζ̤Υ
+* mnstr_t *p : ν̱ʥ󥹥
+***************************************************************/
+
 void	set_act_mnstr_towner( mnstr_t *p )
 {
 	if( p == NULL )
 		return;
 
+	/* ߽ɬפͭСΥ */
+
 	if( set_act_rescue_trgt( p ) )
 		return;
+
+	/* ȤξΥ */
+
 	if( p->attitude == ATTITUDE_MATE ){
 		set_act_pet_std( p );
 		return;
 	}
 
+	/* Ǥʤ顢Υ */
+
 	chk_discount_mark( p );
 	if( p->trgt.kind == TRGT_KIND_QUEUE )
 		return;
 
 	if( p->act.kind == ACT_KIND_DOOR_OPEN ){
+		/* ɥ륢 */
+
 		if( rate_randm( TOWNER_CANCEL_DOOR_RATE ) )
 			clr_chr_trgt_act( p, FALSE );
 	} else {
@@ -188,10 +203,15 @@ void	set_act_mnstr_towner( mnstr_t *p )
 		set_act_towner_enter_door( p );
 	}
 
+	/* ɥФ륢 */
+
 	set_act_towner_exit_door( p );
 }
 
-/**/
+/***************************************************************
+* ν̱ɥ뤫Ĵ٤륢
+* mnstr_t *p : ν̱ʥ󥹥
+***************************************************************/
 
 void	set_act_towner_enter_door( mnstr_t *p )
 {
@@ -214,7 +234,10 @@ void	set_act_towner_enter_door( mnstr_t *p )
 	mark_door( p, dr, DIST_NEAR );
 }
 
-/**/
+/***************************************************************
+* ν̱ɥФ뤫Ĵ٤륢
+* mnstr_t *p : ν̱ʥ󥹥
+***************************************************************/
 
 void	set_act_towner_exit_door( mnstr_t *p )
 {
@@ -261,7 +284,10 @@ void	set_act_towner_exit_door( mnstr_t *p )
 	p->work.enter_door = NULL;
 }
 
-/**/
+/***************************************************************
+* ͧŪʥ󥹥Υ
+* mnstr_t *p : 󥹥
+***************************************************************/
 
 void	set_act_mnstr_friendly( mnstr_t *p )
 {
@@ -271,6 +297,12 @@ void	set_act_mnstr_friendly( mnstr_t *p )
 	set_act_mnstr_std( p );
 }
 
+/***************************************************************
+* ͧŪʥ󥹥αդ
+* mnstr_t *p : 󥹥
+* return : ꤷ?
+***************************************************************/
+
 bool_t	set_act_tame_mnstr( mnstr_t *p )
 {
 	if( p == NULL )
@@ -283,7 +315,11 @@ bool_t	set_act_tame_mnstr( mnstr_t *p )
 	if( p->fx_data.stomach.rate < _100_PERCENT ){
 		item_t	*food;
 
+		/* ʢäƤ */
+
 		do {
+			/* դ */
+
 			food = get_item_food( p,
 					ACT_KIND_ITEM_PICK_UP, FALSE );
 			if( food == NULL )
@@ -300,16 +336,20 @@ bool_t	set_act_tame_mnstr( mnstr_t *p )
 			if( food->y != p->y )
 				break;
 
+			/* ¤򿩤٤ */
+
 			take_meal_chr( p, food->tab.food->fill_rate );
 			del_item( food );
 		} while( 0 );
 	} else {
+		/* ʢäѤˤʤä */
+
 		if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
 			return FALSE;
 
 		mnstr_mark_mbr_std( p );
 		if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) ){
-			/* λ */
+			/* ã */
 			chk_finish_request_join( p->work.request, p );
 		}
 	}
@@ -317,7 +357,11 @@ bool_t	set_act_tame_mnstr( mnstr_t *p )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ν̱ε߽Υ
+* mnstr_t *p : ν̱ʥ󥹥
+* return : ꤷ?
+***************************************************************/
 
 bool_t	set_act_rescue_trgt( mnstr_t *p )
 {
@@ -343,15 +387,20 @@ bool_t	set_act_rescue_trgt( mnstr_t *p )
 	return TRUE;
 }
 
-/**/
-
-/***************************************************************/
+/***************************************************************
+* ƥ󥹥ȼΥ
+***************************************************************/
 
 /*  */
 /* ɥ饴 */
 
 /*  */
 
+/***************************************************************
+* ե˥åΥ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
 void	set_act_mnstr_phoenix( mnstr_t *p )
 {
 	party_t	*pty = get_party();
@@ -361,6 +410,8 @@ void	set_act_mnstr_phoenix( mnstr_t *p )
 		return;
 
 	if( p->attitude != ATTITUDE_MATE ){
+		/* ȤǤʤ̤Υ */
+
 		set_act_mnstr_std( p );
 		return;
 	}
@@ -369,19 +420,30 @@ void	set_act_mnstr_phoenix( mnstr_t *p )
 		if( chk_flg_or( pty->mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
 			continue;
 
+		/* С֤餻 */
+
 		if( chk_flg_or( pty->mbr[i]->stat, FLG_STAT_DEAD ) )
 			fx_resurrection( pty->mbr[i], TRUE );
 	}
 
+	/* ꥿ */
+
 	p->work.dismissal_turn--;
 	if( p->work.dismissal_turn <= 0 ){
 		fx_dismissal( p );
 		return;
 	}
 
+	/* Ĥ̤Υ */
+
 	set_act_mnstr_std( p );
 }
 
+/***************************************************************
+* ˥Υ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
 void	set_act_mnstr_unicorn( mnstr_t *p )
 {
 	party_t	*pty = get_party();
@@ -391,6 +453,8 @@ void	set_act_mnstr_unicorn( mnstr_t *p )
 		return;
 
 	if( p->attitude != ATTITUDE_MATE ){
+		/* ȤǤʤ̤Υ */
+
 		set_act_mnstr_std( p );
 		return;
 	}
@@ -401,20 +465,31 @@ void	set_act_mnstr_unicorn( mnstr_t *p )
 			continue;
 		}
 
-		fx_cure_all_status( pty->mbr[i] );
+		/* Сξְ۾ */
+
+		fx_cure_all_stat( pty->mbr[i] );
 	}
 
+	/* ꥿ */
+
 	p->work.dismissal_turn--;
 	if( p->work.dismissal_turn <= 0 ){
 		fx_dismissal( p );
 		return;
 	}
 
+	/* Ĥ̤Υ */
+
 	set_act_mnstr_std( p );
 }
 
 /*  */
 
+/***************************************************************
+* ץ饳Υ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
 void	set_act_mnstr_leprechaun( mnstr_t *p )
 {
 	chr_t	*mbr;
@@ -422,14 +497,20 @@ void	set_act_mnstr_leprechaun( mnstr_t *p )
 	if( p == NULL )
 		return;
 
+	/* СܤƤ뤫å */
+
 	mbr = mnstr_mark_mbr_adjoin( p );
 
 	if( mbr != NULL ){
+		/* Сζ */
+
 		fx_pick_gold( p, mbr, PICK_GOLD_RATE, PICK_GOLD_MAX_N );
 		print_msg( FLG_NULL, MSG_MNSTR_DISAPPEAR, p->name );
 		teleport_chr( p );
 	}
 
+	/* Ĥ̤Υ */
+
 	set_act_mnstr_std( p );
 }
 
@@ -437,44 +518,70 @@ void	set_act_mnstr_leprechaun( mnstr_t *p )
 
 /* ʪ */
 
+/***************************************************************
+* ʥե饤ȥåפΥ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
 void	set_act_mnstr_venus_fly_trap( mnstr_t *p )
 {
 	if( p == NULL )
 		return;
 
+	/* ܤƤСޤ */
+
 	if( mnstr_mark_mbr_adjoin( p ) != NULL )
-		catch_chr( p, p->trgt.p );
+		catch_chr( p, (chr_t *)(p->trgt.p) );
+
+	/* СȯƤϹ⤹ */
 
 	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
 		mnstr_move_or_atack_std( p );
 }
 
-/**/
+/***************************************************************
+* 饤Υ
+* mnstr_t *p : 󥹥
+***************************************************************/
 
 void	set_act_mnstr_slime( mnstr_t *p )
 {
 	if( p == NULL )
 		return;
 
+	/* Сܤ褦Ȥ */
+
 	if( mnstr_mark_mbr_adjoin( p ) == NULL )
 		mnstr_mark_mbr_std( p );
 
+	/* Ĥ̤Υ */
+
 	set_act_mnstr_std( p );
 }
 
-/**/
+/***************************************************************
+* ݥΥ
+* mnstr_t *p : 󥹥
+***************************************************************/
 
 void	set_act_mnstr_spore( mnstr_t *p )
 {
 	if( p == NULL )
 		return;
 
+	/* СܤƤ⤹ */
+
 	if( mnstr_mark_mbr_adjoin( p ) != NULL )
 		mnstr_move_or_atack_std( p );
 }
 
 /* ưʪ */
 
+/***************************************************************
+* 㥤ȡåȤΥ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
 void	set_act_mnstr_giant_rat( mnstr_t *p )
 {
 	static long	increase_turn = -1;
@@ -482,8 +589,12 @@ void	set_act_mnstr_giant_rat( mnstr_t *p )
 	if( p == NULL )
 		return;
 
+	/* ޤ̤Υ */
+
 	set_act_mnstr_std( p );
 
+	/*  */
+
 	if( increase_turn < get_turn() ){
 		if( rate_randm( INCREASE_RATE_GIANT_RAT ) ){
 			increase_mnstr( p );
@@ -494,6 +605,11 @@ void	set_act_mnstr_giant_rat( mnstr_t *p )
 
 /*  */
 
+/***************************************************************
+* 㥤ȡѥΥ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
 void	set_act_mnstr_giant_spider( mnstr_t *p )
 {
 	mbr_t	*mbr;
@@ -503,10 +619,17 @@ void	set_act_mnstr_giant_spider( mnstr_t *p )
 		return;
 
 	mbr = mnstr_mark_mbr_adjoin( p );
-	if( mbr == NULL )
+	if( mbr == NULL ){
+		/* ܤƤʤʤС̤˶դ */
+
 		mnstr_mark_mbr_std( p );
-	else
+	} else {
+		/* ܤƤʤСޤ */
+
 		catch_chr( p, mbr );
+	}
+
+	/* С뤫å */
 
 	if( mbr == NULL )
 		flg_rel = TRUE;
@@ -515,10 +638,14 @@ void	set_act_mnstr_giant_spider( mnstr_t *p )
 	else
 		flg_rel = FALSE;
 
+	/* СȯƤ */
+
 	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) ){
+		/* С */
 		if( flg_rel )
 			release_chr( p );
 
+		/* ̤˹⤹ */
 		mnstr_move_or_atack_std( p );
 	}
 }
@@ -527,8 +654,15 @@ void	set_act_mnstr_giant_spider( mnstr_t *p )
 
 /* Ⱦ */
 
+/***************************************************************
+* դΥ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
 void	set_act_mnstr_werewolf( mnstr_t *p )
 {
+	/* դѿȤ륢 */
+
 	set_act_mnstr_metamorphose( p, MNSTR_KIND_WOLF, 10 );
 }
 
@@ -537,6 +671,11 @@ void	set_act_mnstr_werewolf( mnstr_t *p )
 /*  */
 /* ʪ */
 
+/***************************************************************
+* 㥤ƥåƥԡɤΥ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
 void	set_act_mnstr_gigantic_centipede( mnstr_t *p )
 {
 	chr_t	*l;
@@ -544,6 +683,8 @@ void	set_act_mnstr_gigantic_centipede( mnstr_t *p )
 	if( p == NULL )
 		return;
 
+	/* ƬǤʤУɤ */
+
 	l = p->work.link_chr;
 	if( l != NULL ){
 		if( (l->pre_x != l->x) || (l->pre_y != l->y) )
@@ -552,6 +693,8 @@ void	set_act_mnstr_gigantic_centipede( mnstr_t *p )
 		return;
 	}
 
+	/* ȤξΥ */
+
 	if( p->attitude == ATTITUDE_MATE ){
 		set_act_pet_std( p );
 		return;
@@ -561,6 +704,8 @@ void	set_act_mnstr_gigantic_centipede( mnstr_t *p )
 
 	mnstr_mark_mbr_std( p );
 
+	/* СȯƤϹ⤹ */
+
 	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
 		mnstr_move_or_atack_std( p );
 }
@@ -569,6 +714,11 @@ void	set_act_mnstr_gigantic_centipede( mnstr_t *p )
 
 /* ˡʪ */
 
+/***************************************************************
+* Υ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
 void	set_act_mnstr_gargoyle( mnstr_t *p )
 {
 	dun_t	*dun = get_dun();
@@ -576,42 +726,54 @@ void	set_act_mnstr_gargoyle( mnstr_t *p )
 	if( p == NULL )
 		return;
 
-	/* begin */
-
 	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) ){
+		/* СȯƤ̤˥ޡ */
+
 		mnstr_mark_mbr_std( p );
 	} else {
 		flg_map_t	flg_map;
 		chr_t	*mark;
 
+		/* Ṳ̄ͤˤ */
 		flg_map = dun->map.obj.flg[p->y][p->x];
 		dun->map.obj.flg[p->y][p->x] |= FLG_MAP_OBJ_PASS;
+
+		/* СܤƤ뤫å */
 		mark = mnstr_mark_mbr_adjoin( p );
+
+		/* λ򸵤᤹ */
 		dun->map.obj.flg[p->y][p->x] = flg_map;
 
+		/* СäѤɽ */
 		if( mark != NULL ){
-			/* Ĥ */
 			dun->map.obj.mjr[p->y][p->x] = FACE_MJR_FLOOR;
 			dun->map.obj.mnr[p->y][p->x] = FACE_MNR_FLOOR;
 			dun->map.obj.flg[p->y][p->x] = FLG_MAP_OBJ_PASS;
 		}
 	}
 
-	/* end */
+	/* СȯƤϹ⤹ */
 
 	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
 		mnstr_move_or_atack_std( p );
 }
 
-/**/
+/***************************************************************
+* ߥߥåΥ
+* mnstr_t *p : 󥹥
+***************************************************************/
 
 void	set_act_mnstr_mimic( mnstr_t *p )
 {
 	if( p == NULL )
 		return;
 
+	/* ܤƤСޤ */
+
 	if( mnstr_mark_mbr_adjoin( p ) != NULL )
-		catch_chr( p, p->trgt.p );
+		catch_chr( p, (chr_t *)(p->trgt.p) );
+
+	/* СȯƤϹ⤹ */
 
 	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
 		mnstr_move_or_atack_std( p );
@@ -621,23 +783,41 @@ void	set_act_mnstr_mimic( mnstr_t *p )
 
 /* ǥå */
 
+/***************************************************************
+* ѥΥ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
 void	set_act_mnstr_vampire( mnstr_t *p )
 {
+	/* 㥤ȡХåȤѿȤ륢 */
+
 	set_act_mnstr_metamorphose( p, MNSTR_KIND_GIANT_BAT, 10 );
 }
 
 /*  */
 
+/***************************************************************
+* 󥭥ХΥ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
 void	set_act_mnstr_incubus( mnstr_t *p )
 {
+	/* ˼դ */
+
 	set_act_mnstr_cubus( p, FEMALE );
 }
 
-/**/
-
+/***************************************************************
+* ХΥ
+* mnstr_t *p : 󥹥
+***************************************************************/
 
 void	set_act_mnstr_succubus( mnstr_t *p )
 {
+	/* ˼դ */
+
 	set_act_mnstr_cubus( p, MALE );
 }
 
