@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr-tab.h,v 1.2 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: mnstr-tab.h,v 1.5 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MNSTR_TAB_H
@@ -35,11 +35,16 @@
 #include	"fight.h"
 #include	"mnstr-act-prot.h"
 
-/**/
+/***************************************************************
+* 󥹥Υǡơ֥
+***************************************************************/
 
-#define	GIGANTIC_CENTIPEDE_LINK_N	8	/* ΤĹ */
+/* 㥤ƥåƥԡɤΤĹ */
+#define	GIGANTIC_CENTIPEDE_LINK_N	8
 
-/* NPC Υꥹ */
+/***************************************************************
+* NPC Υꥹ
+***************************************************************/
 
 mnstr_kind_t	g_ls_npc_kind[] = {
 	MNSTR_KIND_FIGHTER,
@@ -61,13 +66,17 @@ mnstr_kind_t	g_ls_npc_kind[] = {
 	MNSTR_KIND_NULL,
 };
 
-/* 󥹥ǡ */
+/***************************************************************
+* 󥹥ǡ
+***************************************************************/
 
 mnstr_tab_t	mnstr_tab[] = {
 #include	"mnstr-gen-tab.h"
 };
 
-/**/
+/***************************************************************
+* ܥΥꥹ
+***************************************************************/
 
 #if	0
 typedef struct {
@@ -83,8 +92,6 @@ typedef struct {
 } mnstr_lev_tab_t;
 #endif
 
-/* ܥΥꥹ */
-
 mnstr_lev_tab_t	mnstr_boss_lev_tab[] = {
 	{ MNSTR_KIND_HIGH_RE_HOO,	/*  */
 		+0, +1, },
@@ -102,7 +109,9 @@ mnstr_lev_tab_t	mnstr_boss_lev_tab[] = {
 		+0, +0, },
 };
 
-/* 󥹥νиꥹ */
+/***************************************************************
+* 󥹥νиꥹ
+***************************************************************/
 
 mnstr_lev_tab_t	mnstr_lev_tab[] = {
 	{ MNSTR_KIND_FIGHTER,	/* ʹ */
@@ -367,9 +376,9 @@ mnstr_lev_tab_t	mnstr_lev_tab[] = {
 		+0, +0, },
 };
 
-/***************************************************************/
-
-/* Ǥ NPC νиΨꥹ */
+/***************************************************************
+* Ǥ NPC νиΨꥹ
+***************************************************************/
 
 typedef struct {
 	mnstr_kind_t	kind;
@@ -427,7 +436,7 @@ towner_tab_t	towner_tab[] = {
 	},
 	{
 		MNSTR_KIND_CRAFTSMAN,
-		5,
+		3,
 	},
 	{
 		MNSTR_KIND_MERCHANT,
