@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.166 2006/01/15 14:05:51 bowkenken Exp $
+* $Id: mnstr.c,v 1.168 2006/02/03 14:21:02 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -771,15 +771,13 @@ mbr_t	*mnstr_mark_mbr_common( mnstr_t *p, sex_t sex )
 		long	tmp_r;
 
 		if( chk_flg_or( pty->mbr[i]->stat,
-				FLG_STAT_NOT_EXIST
-				| FLG_STAT_DEAD
-				| FLG_STAT_VANISH ) ){
+				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
 			continue;
 		}
-
 		if( !chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) ){
-			if( !chk_find_chr( p, pty->mbr[i] ) )
+			if( !chk_find_chr( p, pty->mbr[i] ) ){
 				continue;
+			}
 		}
 
 		if( sex != SEX_NULL )
@@ -804,10 +802,6 @@ mbr_t	*mnstr_mark_mbr_common( mnstr_t *p, sex_t sex )
 				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
 			continue;
 		}
-
-		if( chk_flg( pty_pet[i]->stat, FLG_STAT_VANISH ) )
-			continue;
-
 		if( !chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) ){
 			if( !chk_find_chr( p, pty_pet[i] ) )
 				continue;
@@ -894,7 +888,9 @@ mbr_t	*mnstr_mark_mbr_adjoin( mnstr_t *p )
 		if( pty_pet[i] == NULL )
 			break;
 		if( chk_flg_or( pty_pet[i]->stat,
-				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+				FLG_STAT_NOT_EXIST
+				| FLG_STAT_DEAD
+				| FLG_STAT_VANISH ) ){
 			continue;
 		}
 		if( labs( p->x - pty_pet[i]->x ) > 1 )
@@ -1630,6 +1626,58 @@ mnstr_kind_t	get_npc_kind_randm( void )
 	return g_ls_npc_kind[n];
 }
 
+/***************************************************************
+* 󥹥η֤̾
+* char mjr : 󥹥Υ᥸㡼δʸ
+* return : 󥹥η̾
+***************************************************************/
+
+char	*get_mnstr_mjr_name( char mjr )
+{
+	switch( mjr ){
+	case FACE_MJR_MNSTR_GOD:
+		return MSG_MNSTR_MJR_NAME_GOD;
+	case FACE_MJR_MNSTR_DRAGON:
+		return MSG_MNSTR_MJR_NAME_DRAGON;
+	case FACE_MJR_MNSTR_ILLUSORY:
+		return MSG_MNSTR_MJR_NAME_ILLUSORY;
+	case FACE_MJR_MNSTR_FAIRY:
+		return MSG_MNSTR_MJR_NAME_FAIRY;
+	case FACE_MJR_MNSTR_ELEMENTAL:
+		return MSG_MNSTR_MJR_NAME_ELEMENTAL;
+	case FACE_MJR_MNSTR_PLANT:
+		return MSG_MNSTR_MJR_NAME_PLANT;
+	case FACE_MJR_MNSTR_ANIMAL:
+		return MSG_MNSTR_MJR_NAME_ANIMAL;
+	case FACE_MJR_MNSTR_INSECT:
+		return MSG_MNSTR_MJR_NAME_INSECT;
+	case FACE_MJR_MNSTR_HUMAN:
+		return MSG_MNSTR_MJR_NAME_HUMAN;
+	case FACE_MJR_MNSTR_HYBRID:
+		return MSG_MNSTR_MJR_NAME_HYBRID;
+	case FACE_MJR_MNSTR_GIANT:
+		return MSG_MNSTR_MJR_NAME_GIANT;
+	case FACE_MJR_MNSTR_HUGE:
+		return MSG_MNSTR_MJR_NAME_HUGE;
+	case FACE_MJR_MNSTR_AQUATIC:
+		return MSG_MNSTR_MJR_NAME_AQUATIC;
+	case FACE_MJR_MNSTR_MAGICAL:
+		return MSG_MNSTR_MJR_NAME_MAGICAL;
+	case FACE_MJR_MNSTR_COMPOUND:
+		return MSG_MNSTR_MJR_NAME_COMPOUND;
+	case FACE_MJR_MNSTR_UNDEAD:
+		return MSG_MNSTR_MJR_NAME_UNDEAD;
+	case FACE_MJR_MNSTR_EVIL:
+		return MSG_MNSTR_MJR_NAME_EVIL;
+	case FACE_MJR_MNSTR_EVIL_BEAST:
+		return MSG_MNSTR_MJR_NAME_EVIL_BEAST;
+	case FACE_MJR_MNSTR_DEVIL:
+		return MSG_MNSTR_MJR_NAME_DEVIL;
+	}
+
+	return MSG_MNSTR_MJR_NAME_UNKNOWN;
+}
+
 /***************************************************************
 * 󥹥̾ǡơ֥뤫鸡
 * mnstr_kind_t mnstr_kind : 󥹥μ
