@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,30 +25,41 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.h,v 1.30 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: mnstr.h,v 1.33 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MNSTR_H
 #define	MNSTR_H
 
-/* 󥹥 */
+/***************************************************************
+* 󥹥
+***************************************************************/
 
 #include	"chr.h"
 #include	"mnstr-kind.h"
 
+/* 󥹥ο */
 
-#define	MNSTR_MAX_N	128	/*  */
-#define	MNSTR_AVE_N	16	/* ʿѽи */
+/*  */
+#define	MNSTR_MAX_N	128
+/* ʿѽи */
+#define	MNSTR_AVE_N	16
 
 /* 󥹥ư롢Υκ */
 #define	MNSTR_MOVE_MAX_X	(AREA_MAX_X * 4 + 0)
 #define	MNSTR_MOVE_MAX_Y	(AREA_MAX_Y * 4 + 0)
-#define	MNSTR_NEAR_R	4	/* ᤤȽǤΥ */
+
+/* ᤤȽǤΥ */
+#define	MNSTR_NEAR_R	4
 
 /* 󥹥ɤݤȥСΥ٥뤬夬뤫ܰ */
 #define	EXP_NEED_KILL_MNSTR_N	20
 
-/**/
+/***************************************************************
+* ǡ
+***************************************************************/
+
+/* 󥹥Υǡ */
 
 typedef chr_t	mnstr_t;
 
@@ -58,7 +69,7 @@ typedef struct {
 	long	x, y;
 } mnstr_null_t;
 
-/**/
+/* 󥹥νиΥǡ */
 
 typedef struct {
 	/* 󥹥μ */
