@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,53 +25,11 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.156 2004/12/25 03:14:04 bowkenken Exp $
+* $Id: party.c,v 1.167 2006/01/15 14:05:51 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-/*#include	"misc.h"*/
-/*#include	"turn.h"*/
-/*#include	"dun.h"*/
-#include	"town.h"
-#include	"item.h"
-#include	"spell.h"
-/*#include	"chr.h"*/
-/*#include	"party.h"*/
-/*#include	"mnstr.h"*/
-#include	"pet.h"
-/*#include	"fight.h"*/
-/*#include	"fx.h"*/
-/*#include	"trap.h"*/
-#include	"draw.h"
-/*#include	"curs.h"*/
-#include	"menu.h"
-#include	"amenu.h"
-/*#include	"request.h"*/
-/*#include	"gfile.h"*/
-/*#include	"msg.h"*/
-/*#include	"ver.h"*/
-#include	"gmain-prot.h"
-#include	"misc-prot.h"
-/*#include	"turn-prot.h"*/
-#include	"dun-prot.h"
-#include	"town-prot.h"
-#include	"item-prot.h"
-#include	"spell-prot.h"
-#include	"chr-prot.h"
-#include	"party-prot.h"
-#include	"mnstr-prot.h"
-#include	"pet-prot.h"
-#include	"fight-prot.h"
-#include	"fx-prot.h"
-#include	"trap-prot.h"
-#include	"draw-prot.h"
-#include	"curs-prot.h"
-#include	"menu-prot.h"
-/*#include	"tmenu-prot.h"*/
-#include	"amenu-prot.h"
-/*#include	"request-prot.h"*/
-/*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
+#define	PARTY_C
+#include	"inc.h"
 
 /**/
 
@@ -294,7 +252,7 @@ void	init_party_dflt( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_CAT;
-	strncpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
+	strncpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[7], "----EYE-------|===", 'Y', race,
 			FEMALE, CLASS_N_SUMMONER, 7 );
 
@@ -493,7 +451,7 @@ void	init_party_debug( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_CAT;
-	strncpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
+	strncpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[7], "----EYE-------|===", 'Y', race,
 			FEMALE, CLASS_N_SUMMONER, 7 );
 
@@ -751,27 +709,27 @@ void	init_party_debug( void )
 			TRUE, FALSE, FALSE );
 	inc_item( item, +16 );
 
-	i = 5;
+	i = 3;
 	sub_kind.potion = POTION_KIND_RESI_PHYS;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			FALSE, FALSE, FALSE );
 
-	i = 5;
+	i = 3;
 	sub_kind.potion = POTION_KIND_STRENGTH;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			FALSE, FALSE, FALSE );
 
-	i = 5;
+	i = 3;
 	sub_kind.potion = POTION_KIND_DULLNESS;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			FALSE, FALSE, FALSE );
 
-	i = 5;
+	i = 3;
 	sub_kind.potion = POTION_KIND_POISON;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			FALSE, FALSE, FALSE );
 
-	i = 5;
+	i = 3;
 	sub_kind.potion = POTION_KIND_FLY;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			FALSE, FALSE, FALSE );
@@ -808,6 +766,32 @@ void	init_party_debug( void )
 	init_mbr_item( ls_mbr[i], ITEM_KIND_STICK, &sub_kind,
 			TRUE, FALSE, FALSE );
 
+	/* stick */
+
+	i = 5;
+	sub_kind.mnstr = MNSTR_KIND_A_GOLD_DRAGON;
+	item = init_mbr_item( ls_mbr[i], ITEM_KIND_BONE, &sub_kind,
+			TRUE, FALSE, FALSE );
+	inc_item( item, +1 );
+
+	i = 5;
+	sub_kind.mnstr = MNSTR_KIND_MORMIN_TROLL;
+	item = init_mbr_item( ls_mbr[i], ITEM_KIND_BONE, &sub_kind,
+			TRUE, FALSE, FALSE );
+	inc_item( item, +1 );
+
+	i = 7;
+	sub_kind.mnstr = MNSTR_KIND_A_GOLD_DRAGON;
+	item = init_mbr_item( ls_mbr[i], ITEM_KIND_BONE, &sub_kind,
+			TRUE, FALSE, FALSE );
+	inc_item( item, +1 );
+
+	i = 7;
+	sub_kind.mnstr = MNSTR_KIND_WOLF;
+	item = init_mbr_item( ls_mbr[i], ITEM_KIND_BONE, &sub_kind,
+			TRUE, FALSE, FALSE );
+	inc_item( item, +1 );
+
 	/* misc */
 
 	i = 0;
@@ -910,6 +894,7 @@ item_t	*init_mbr_item(
 	case ITEM_KIND_TOBACCO:
 	case ITEM_KIND_PIPE:
 	case ITEM_KIND_RARE_GOODS:
+	case ITEM_KIND_BONE:
 	case ITEM_KIND_COIN:
 		if( sub_kind == NULL )
 			return NULL;
@@ -991,6 +976,8 @@ item_t	*init_mbr_item(
 		tab_n = get_rare_goods_tab_n( get_rare_goods_tab(
 				sub_kind->rare_goods ) );
 		break;
+	case ITEM_KIND_BONE:
+		break;
 	case ITEM_KIND_COIN:
 		tab_n = get_coin_tab_n( get_coin_tab(
 				sub_kind->coin ) );
@@ -1058,6 +1045,10 @@ item_t	*init_mbr_item(
 	case ITEM_KIND_RARE_GOODS:
 		item = make_item_rare_goods( lev, tab_n );
 		break;
+	case ITEM_KIND_BONE:
+		item = make_item_bone( lev,
+				get_mnstr_tab( sub_kind->mnstr, lev ) );
+		break;
 	case ITEM_KIND_COIN:
 		item = make_item_coin( lev, tab_n );
 		break;
@@ -1177,7 +1168,8 @@ void	new_mbr(
 		lev = abl_init[mbr->race.main][i];
 
 		mbr->abl.lev[i].max = lev;
-		mbr->abl.exp[i].max = calc_lev_to_exp( lev, i );
+		mbr->abl.exp[i].max = calc_lev_to_exp(
+				lev, (abl_kind_t)i );
 
 		mbr->abl.lev[i].n = mbr->abl.lev[i].max;
 		mbr->abl.lev[i].add = 0;
@@ -1267,7 +1259,7 @@ void	new_mbr(
 
 bool_t	reset_mbr_resi( mbr_t *mbr )
 {
-	resi_kind_t	k;
+	long	k;
 
 	if( mbr == NULL )
 		return FALSE;
@@ -1399,11 +1391,27 @@ void	appear_party( void )
 					MAP_MAX_X / 2,
 					MAP_MAX_Y / 2 );
 		}
+	} else {
+		set_map_all_mbr();
 	}
 
-	set_map_all_mbr();
-
 	appear_all_pet();
+
+	next_pos_square( 0 );
+	scroll_center_appear_party();
+	set_flg_find_all_mnstr();
+
+	redraw_all();
+}
+
+/**/
+
+void	scroll_center_appear_party( void )
+{
+	if( chk_flg_or( get_flg_scroll(),
+			(FLG_SCROLL_CENTER | FLG_SCROLL_SMOOTH) ) ){
+		scroll_center();
+	}
 }
 
 /**/
@@ -1599,7 +1607,7 @@ void	die_mbr( mbr_t *mbr, bool_t flg_chk_game_over )
 	if( i >= MBR_MAX_N ){
 		print_msg( FLG_MSG_NO_MORE_PREV, MSG_S, MSG_GAME_OVER );
 		while( 1 ){
-			switch( get_key( TRUE ) ){
+			switch( get_key( g_flg_clr_key_buf ) ){
 			case 'C' - '@':
 			case 'Q' - '@':
 				exit_game( EXIT_SUCCESS );
@@ -1790,7 +1798,7 @@ void	collect_gold( mbr_t *mbr )
 
 	add_chr_gold( mbr, gold );
 
-	print_msg( FLG_NULL, MSG_COLLECT_GOLD, mbr->name, gold );
+	print_msg( FLG_NULL, MSG_COLLECT_GOLD, mbr->name, fmt_gold( gold ) );
 }
 
 /**/
@@ -1851,7 +1859,50 @@ void	divide_gold( void )
 
 	add_chr_gold( party.mbr[mod_n], sum );
 
-	print_msg( FLG_NULL, MSG_DIVIDE_GOLD, gold );
+	print_msg( FLG_NULL, MSG_DIVIDE_GOLD, fmt_gold( gold ) );
+}
+
+/**/
+
+void	give_gold( mbr_t *mbr_from, mbr_t *mbr_to, gold_t gold )
+{
+	bool_t	flg_force;
+	gold_t	res_price, max;
+
+	if( mbr_from == NULL )
+		return;
+	if( mbr_to == NULL )
+		return;
+
+	/* Ѥ GOLD ϵݽʤ */
+
+	res_price = get_price_temple_resurrection( mbr_to );
+	flg_force = FALSE;
+	if( chk_flg( mbr_to->stat, FLG_STAT_DEAD )
+			&& (get_chr_gold( mbr_to ) < res_price)
+			&& (mbr_to->fx_data.friend_turn > 0) ){
+		flg_force = TRUE;
+	}
+
+	/* GOLD Τ */
+
+	if( mbr_to->fx_data.friend_turn > 0 ){
+		if( !flg_force ){
+			print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
+					mbr_to->name );
+			return;
+		}
+	}
+
+	max = GOLD_MAX - get_chr_gold( mbr_to );
+	if( gold > max )
+		gold = max;
+
+	add_chr_gold( mbr_from, -gold );
+	add_chr_gold( mbr_to, +gold );
+
+	print_msg( FLG_NULL, MSG_GIVE_GOLD,
+			mbr_from->name, fmt_gold( gold ), mbr_to->name );
 }
 
 /**/
@@ -1899,7 +1950,7 @@ void	add_party_gold( gold_t gold )
 		return;
 
 	curs_attrset_chr( party.mbr[mod_n], +1, FALSE );
-	print_msg( FLG_NULL, MSG_ADD_PARTY_GOLD, gold );
+	print_msg( FLG_NULL, MSG_ADD_PARTY_GOLD, fmt_gold( gold ) );
 	curs_attrset_dflt();
 
 	div_gold = gold / n;
@@ -1939,7 +1990,7 @@ gold_t	sub_party_gold( gold_t gold )
 
 	curs_attrset_chr( get_mbr_randm( MAP_DEL_X, MAP_DEL_Y ),
 			-1, FALSE );
-	print_msg( FLG_NULL, MSG_SUB_PARTY_GOLD, gold );
+	print_msg( FLG_NULL, MSG_SUB_PARTY_GOLD, fmt_gold( gold ) );
 	curs_attrset_dflt();
 
 	div_gold = gold / n;
@@ -2647,7 +2698,7 @@ bool_t	remove_class( long class_n )
 
 bool_t	cmp_class( class_t *org, class_t *dst )
 {
-	abl_kind_t	abl;
+	long	abl;
 
 	if( strncmp( org->name, dst->name, CLASS_NAME_MAX_LEN ) != 0 )
 		return FALSE;
