@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.147 2006/01/15 15:16:09 bowkenken Exp $
+* $Id: spell.c,v 1.148 2006/02/17 04:45:36 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -59,6 +59,17 @@
 
 #define	BAR_LIMIT_LEV	10
 
+enum {
+	LS_MBR_N_BLADE,
+	LS_MBR_N_DRANK,
+	LS_MBR_N_ELSIE,
+	LS_MBR_N_CECILE,
+	LS_MBR_N_HALLE,
+	LS_MBR_N_BEAUT,
+	LS_MBR_N_GOKOU,
+	LS_MBR_N_EYE,
+};
+
 /**/
 
 static cast_tab_t	cast_tab[LS_MBR_MAX_N][SPELL_KIND_MAX_N];
@@ -141,12 +152,12 @@ void	init_spell_debug( void )
 	long	k;
 
 #if	0
-	m = 0;
+	m = LS_MBR_N_BLADE;
 	for( k = SPELL_KIND_NIN_MIN_N + 1; k < SPELL_KIND_NIN_MAX_N; k++ )
 		cast_tab[m][k].flg_cast = TRUE;
 #endif
 
-	m = 3;
+	m = LS_MBR_N_CECILE;
 	for( k = SPELL_KIND_PRI_MIN_N + 1; k < SPELL_KIND_PRI_MAX_N; k++ ){
 		if( k == SPELL_KIND_CURE_PARALYZE )
 			continue;
@@ -156,7 +167,7 @@ void	init_spell_debug( void )
 		cast_tab[m][k].flg_cast = TRUE;
 	}
 
-	m = 4;
+	m = LS_MBR_N_HALLE;
 	for( k = SPELL_KIND_BAR_MIN_N + 1; k < SPELL_KIND_BAR_MAX_N; k++ ){
 		if( k == SPELL_KIND_SONG_DULLNESS )
 			continue;
@@ -164,7 +175,7 @@ void	init_spell_debug( void )
 		cast_tab[m][k].flg_cast = TRUE;
 	}
 
-	m = 5;
+	m = LS_MBR_N_BEAUT;
 	for( k = SPELL_KIND_NULL + 1; k < SPELL_KIND_MAX_N; k++ ){
 		if( k == SPELL_KIND_CREATE_FOOD )
 			continue;
@@ -175,12 +186,12 @@ void	init_spell_debug( void )
 	}
 
 #if	0
-	m = 5;
+	m = LS_MBR_N_BEAUT;
 	for( k = SPELL_KIND_SHA_MIN_N + 1; k < SPELL_KIND_SHA_MAX_N; k++ )
 		cast_tab[m][k].flg_cast = FALSE;
 #endif
 
-	m = 7;
+	m = LS_MBR_N_EYE;
 	for( k = SPELL_KIND_SUM_MIN_N + 1; k < SPELL_KIND_SUM_MAX_N; k++ )
 		cast_tab[m][k].flg_cast = TRUE;
 }
@@ -189,13 +200,14 @@ void	init_spell_debug( void )
 
 void	init_spell_dflt( void )
 {
-	/* CECILE */
+	long	m;
 
-	cast_tab[3][SPELL_KIND_CURE_HP_LIGHT].flg_cast = TRUE;
+	m = LS_MBR_N_CECILE;
+	cast_tab[m][SPELL_KIND_CURE_HP_LIGHT].flg_cast = TRUE;
 
-	/* BEAUT */
-
-	cast_tab[5][SPELL_KIND_LIGHT].flg_cast = TRUE;
+	m = LS_MBR_N_BEAUT;
+	cast_tab[m][SPELL_KIND_LIGHT].flg_cast = TRUE;
+	cast_tab[m][SPELL_KIND_STORE_LIGHT].flg_cast = TRUE;
 }
 
 /**/
@@ -1487,6 +1499,9 @@ void	chr_cast_spell_sub(
 	case SPELL_KIND_DARKNESS:
 		fx_darkness( x, y );
 		break;
+	case SPELL_KIND_STORE_LIGHT:
+		fx_store_light( chr );
+		break;
 	case SPELL_KIND_TELEPORT_PARTY:
 		fx_teleport_party();
 		break;
@@ -2092,6 +2107,7 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 		break;
 	case SPELL_KIND_LIGHT:
 	case SPELL_KIND_DARKNESS:
+	case SPELL_KIND_STORE_LIGHT:
 	case SPELL_KIND_TELEPORT_PARTY:
 	case SPELL_KIND_TELEPORT:
 	case SPELL_KIND_RECALL:
@@ -2792,6 +2808,7 @@ char	*get_spell_vfx_str( spell_kind_t spell_kind )
 	case SPELL_KIND_MAG_MIN_N:
 	case SPELL_KIND_LIGHT:
 	case SPELL_KIND_DARKNESS:
+	case SPELL_KIND_STORE_LIGHT:
 	case SPELL_KIND_TELEPORT_PARTY:
 	case SPELL_KIND_TELEPORT:
 	case SPELL_KIND_RECALL:
