@@ -95,6 +95,7 @@ char	*cb_menu_bar_save( menu_t **pp, menu_t **dflt );
 char	*menu_inn( void );
 char	*cb_menu_inn_stay( menu_t **pp, menu_t **dflt );
 char	*cb_menu_inn_short_stay( menu_t **pp, menu_t **dflt );
+char	*cb_menu_inn_bath( menu_t **pp, menu_t **dflt );
 char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_magic_guild( menu_t **pp, menu_t **dflt );
 char	*cb_menu_magic_guild_no_learn( menu_t **pp, menu_t **dflt );
@@ -109,6 +110,9 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt );
 char	*cb_menu_pet_shop_remove_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt );
 char	*cb_menu_pet_shop_buy_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_navi_init( menu_t **pp, menu_t **dflt );
+char	*cb_menu_navi( menu_t **pp, menu_t **dflt );
+char	*cb_menu_navi_stairs( menu_t **pp, menu_t **dflt );
 
 #ifdef __cplusplus
 }
