@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu-tab.h,v 1.13 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: tmenu-tab.h,v 1.16 2006/02/17 04:45:36 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TMENU_TAB_H
@@ -207,6 +207,16 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/magic guild/MAG/store_light",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_STORE_LIGHT, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_STORE_LIGHT,
+		FLG_NULL,
+	},
+
 	{
 		"/magic guild/MAG/teleport_party",
 		"<Branch>",
@@ -1750,6 +1760,15 @@ menu_t	ls_menu_inn[] = {
 		cb_menu_inn_short_stay, (void *)TRUE,
 		FLG_NULL,
 	},
+	{
+		"/inn/bath",
+		"<Branch>",
+		'B',
+		"",
+		N_MSG_MENU_INN_BATH, "",
+		cb_menu_inn_bath, NULL,
+		FLG_NULL,
+	},
 	{
 		"/inn/divide gold",
 		"<Item>",
@@ -1857,4 +1876,6 @@ menu_t	ls_menu_pet_shop_remove[1 + 1 + (LS_PET_MAX_N * 2) + 1];
 menu_t	ls_menu_pet_shop_buy[
 	1 + 1 + PET_SHOP_PET_MAX_N + PET_SHOP_PAGE_MAX_N + 1];
 
+menu_t	ls_menu_navi[1 + 1 + SHOP_N_MAX_N + 1];
+
 #endif	/* TMENU_TAB_H */
