@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.86 2006/01/15 15:16:09 bowkenken Exp $
+* $Id: tmenu.c,v 1.90 2006/02/15 01:24:22 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -61,6 +61,8 @@ static item_t	*g_sel_art;
 static long	g_sel_class_n;
 static item_t	*g_mbr_order[MBR_MAX_N];
 
+static menu_t	*g_navi_dflt;
+
 /**/
 
 void	init_tmenu( void )
@@ -72,6 +74,8 @@ void	init_tmenu( void )
 	g_sel_ls_mbr = ls_mbr[0];
 	g_sel_art = NULL;
 	g_sel_class_n = 0;
+
+	g_navi_dflt = NULL;
 }
 
 /**/
@@ -2589,6 +2593,28 @@ char	*cb_menu_inn_short_stay( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_inn_bath( menu_t **pp, menu_t **dflt )
+{
+	char	*str_goto;
+	mbr_t	*mbr;
+
+	str_goto = NULL;
+
+	while( 1 ){
+		str_goto = exec_menu_sel_mbr(
+				&mbr, MSG_TTL_MENU_INN_BATH,
+				FALSE, TRUE );
+		if( str_goto != NULL )
+			break;
+
+		take_bath( mbr );
+	}
+
+	return str_goto;
+}
+
+/**/
+
 char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 {
 	menu_t	*ls, *p;
@@ -3382,3 +3408,98 @@ char	*cb_menu_pet_shop_buy_sel( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_navi_init( menu_t **pp, menu_t **dflt )
+{
+	menu_t	*ls;
+	long	k;
+	long	i;
+
+	set_menu_dflt_main( *pp );
+
+	*dflt = NULL;
+	ls = ls_menu_navi;
+	k = 0;
+
+	strncpy( ls[k].path, "/navi", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	ls[k].msg[0] = '\0';
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	strncpy( ls[k].path, "/navi/title", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	strncpy( ls[k].msg, MSG_TTL_MENU_NAVI, MENU_MSG_MAX_LEN );
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	strncpy( ls[k].path, "/navi/stairs", MENU_PATH_MAX_LEN );
+	strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+	ls[k].accel_key = 'Z';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NAVI_PARTY_STAIRS;
+	ls[k].msg[0] = '\0';
+	ls[k].call_back = cb_menu_navi_stairs;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	for( i = SHOP_N_NULL + 1; i < SHOP_N_MAX_N; i++ ){
+		char	mnr;
+		shop_n_t	n;
+
+		n = (shop_n_t)i;
+		mnr = get_shop_mnr_face( n );
+
+		sprintf( ls[k].path, "/navi/%c", (char)mnr );
+		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		ls[k].accel_key = toupper( mnr );
+		ls[k].short_key[0] = '\0';
+		ls[k].n_msg = N_MSG_NULL,
+		strncpy( ls[k].msg, get_shop_name( n ), MENU_MSG_MAX_LEN );
+		ls[k].call_back = cb_menu_navi;
+		ls[k].arg = (void *)n;
+		ls[k].flg = FLG_NULL;
+		k++;
+	}
+	ls[k].path[0] = '\0';
+
+	*pp = ls;
+	*dflt = g_navi_dflt;
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_navi( menu_t **pp, menu_t **dflt )
+{
+	g_navi_dflt = *pp;
+
+	navi_party( (shop_n_t)((*pp)->arg) );
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_navi_stairs( menu_t **pp, menu_t **dflt )
+{
+	g_navi_dflt = *pp;
+
+	navi_party_stairs();
+
+	return NULL;
+}
+
+/**/
+
