@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.112 2006/01/15 15:16:09 bowkenken Exp $
+* $Id: town.c,v 1.117 2006/02/15 01:24:22 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -37,6 +37,9 @@
 
 /**/
 
+#define	SHOP_ADD_TURN_N	(15 * TURN_PER_MINUTE)
+#define	NAVI_ADD_TURN_N	((MAP_MAX_X + MAP_MAX_Y) / 2)
+
 #define	OPEN_TURN_BAR	( 0 * TURN_PER_HOUR)
 #define	CLOSE_TURN_BAR	(24 * TURN_PER_HOUR)
 #define	OPEN_TURN_INN	( 0 * TURN_PER_HOUR)
@@ -64,8 +67,6 @@
 #define	OPEN_TURN_PET_SHOP	( 7 * TURN_PER_HOUR)
 #define	CLOSE_TURN_PET_SHOP	(19 * TURN_PER_HOUR)
 
-#define	SHOP_ADD_TURN_N	(15 * TURN_PER_MINUTE)
-
 /**/
 
 #define	ART_LEVEL_WPN	-20
@@ -188,6 +189,10 @@
 
 discount_queue_t	g_discount_queue;
 
+/* ϤΤΨ */
+
+#define	MBR_IS_MOLESTED_RATE	((rate_t)10)
+
 /**/
 
 #define	STR_XPM_COL_NONE	"None"
@@ -1221,6 +1226,38 @@ bool_t	appear_party_town( void )
 
 /**/
 
+bool_t	navi_party( shop_n_t shop_n )
+{
+	door_t	*dr;
+
+	dr = get_shop_door( shop_n );
+	if( dr == NULL )
+		return FALSE;
+
+	add_turn( NAVI_ADD_TURN_N );
+	print_msg( FLG_NULL, MSG_NAVI_PARTY, get_shop_name( shop_n ) );
+
+	open_door_shop( dr->n );
+	exec_all_phase();
+
+	return TRUE;
+}
+
+/**/
+
+bool_t	navi_party_stairs()
+{
+	if( !appear_party_town() )
+		return FALSE;
+
+	add_turn( NAVI_ADD_TURN_N );
+	print_msg( FLG_NULL, MSG_NAVI_PARTY, MSG_NAVI_PARTY_STAIRS );
+
+	return TRUE;
+}
+
+/**/
+
 bool_t	open_door_shop( long n )
 {
 	dun_t	*dun;
@@ -1398,6 +1435,9 @@ void	party_exit_shop( long dr_n )
 
 	set_flg_find_all_mnstr();
 	wipe_menu();
+
+	move_crsr_abs( pty->square.x, pty->square.y );
+
 	add_turn( SHOP_ADD_TURN_N );
 }
 
@@ -1579,7 +1619,7 @@ void	stay_inn( bool_t flg_short_stay )
 		learn_spell_bar( mbr );
 
 		/* Ȥ */
-		take_meal_fill_chr( mbr );
+		/* take_meal_fill_chr( mbr ); */
 
 		/* ̤ۤդ */
 		clean_all_disposal( mbr );
@@ -1635,6 +1675,36 @@ void	stay_inn( bool_t flg_short_stay )
 	}
 }
 
+/***************************************************************
+* 饯Ϥ
+* chr_t *chr : 饯
+***************************************************************/
+
+void	take_bath( chr_t *chr )
+{
+	if( chr == NULL )
+		return;
+
+	print_msg( FLG_NULL, MSG_TAKE_BATH, chr->name );
+
+	if( chr->kind == CHR_KIND_MBR ){
+		print_words( chr->name, chr->sex.cur,
+				MSG_WORDS_TAKE_BATH_FAMALE,
+				MSG_WORDS_TAKE_BATH_MALE );
+
+		/* ԴˤΤ줿 */
+
+		if( rate_randm( MBR_IS_MOLESTED_RATE ) ){
+			print_msg( FLG_NULL, MSG_CHR_IS_MOLESTED,
+					chr->name );
+
+			print_words( chr->name, chr->sex.cur,
+					MSG_WORDS_CHR_IS_MOLESTED_FAMALE,
+					MSG_WORDS_CHR_IS_MOLESTED_MALE );
+		}
+	}
+}
+
 /**/
 
 bool_t	set_art_name( mbr_t *mbr, item_t *art, deal_kind_t kind )
