@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.c,v 1.51 2006/01/15 15:16:09 bowkenken Exp $
+* $Id: trap.c,v 1.54 2006/02/04 08:11:47 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -38,15 +38,21 @@
 /***************************************************************/
 
 /*  */
+
 #define	TRAP_DIFFICULTY_LEV_RATE	RATE_LEV_PER_DUN_LEV
 #define	TRAP_DIFFICULTY_LEV_ADD	1
 
-/* ˻ųݤƤΨ */
-#define	TRAP_ROOM_RATE	((rate_t)1)
+/* ȥåνиΨ */
+
+/* и㳬 */
+#define	TRAP_ROOM_DUN_LEV_MIN_N	30
+/* иΨ */
+#define	TRAP_ROOM_RATE	((rate_t)3)
 /* ˻ųݤƤ */
 #define	TRAP_ROOM_N	50
 
 /* Υ᡼( HP  %) */
+
 #define	PIT_DAM_RATE	((rate_t)25)
 #define	PIT_DAM_ADD	1
 
@@ -397,7 +403,29 @@ bool_t	set_trap_face_mnr( trap_t *trap )
 }
 
 /***************************************************************
-* ʣ櫤Ϥ
+* ȥåϤ
+* long area_x : X ꥢɸ
+* long area_y : Y ꥢɸ
+* long dun_lev : µܥ٥
+***************************************************************/
+
+void	make_chk_trap_room( long dun_lev )
+{
+	long	x, y;
+
+	if( labs( dun_lev ) < TRAP_ROOM_DUN_LEV_MIN_N )
+		return;
+	if( !rate_randm( TRAP_ROOM_RATE ) )
+		return;
+
+	x = randm( AREA_MAP_MAX_X );
+	y = randm( AREA_MAP_MAX_Y );
+
+	make_trap_room( x, y, dun_lev );
+}
+
+/***************************************************************
+* ȥåʣ櫤Ϥ
 * long area_x : X ꥢɸ
 * long area_y : Y ꥢɸ
 * long dun_lev : µܥ٥
@@ -409,9 +437,6 @@ void	make_trap_room( long area_x, long area_y, long dun_lev )
 	long	n;
 	long	i;
 
-	if( !rate_randm( TRAP_ROOM_RATE ) )
-		return;
-
 	n = 0;
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
 		long	mx, my;
