@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: ver.h,v 1.39 2004/12/07 06:41:08 bowkenken Exp $
+* $Id: ver.h,v 1.42 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	VER_H
@@ -34,7 +34,7 @@
 #define	STR_FILE_NAME_GAME	"lnl"
 #define	STR_TITLE	"L&L - Labyrinths & Legends :"
 #define	STR_SINCE	"1993"
-#define	STR_LATEST	"2004"
+#define	STR_LATEST	"2006"
 #define	STR_AUTHOR	"YOSHIMURA Tomohiko"
 #define	STR_HANDLE1	"BowKenKen"
 #define	STR_HANDLE2	""
@@ -52,7 +52,7 @@
 		"\n" \
 		"Created by %s, %s\n" \
 		"URL   : %s\n" \
-		"e-mail: %s\n" \
+		"E-mail: %s\n" \
 		"\n" \
 		"Special thanks %s and you.\n" \
 		"--------------------------------" \
