@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDun.cpp,v 1.21 2006/01/12 08:51:40 bowkenken Exp $
+* $Id: PcgDun.cpp,v 1.23 2006/02/02 19:37:24 bowkenken Exp $
 ***************************************************************/
 
 #include	"gmain.h"
@@ -66,7 +66,9 @@
 //#include	"trap-prot.h"
 #include	"draw-prot.h"
 //#include	"curs-prot.h"
-#include	"menu-prot.h"
+//#include	"menu-prot.h"
+#include	"mmenu-prot.h"
+//#include	"imenu-prot.h"
 //#include	"tmenu-prot.h"
 //#include	"amenu-prot.h"
 //#include	"request-prot.h"
@@ -542,6 +544,8 @@ break;//@@@
 
 		aMnstr[i][j].dis();
 	}
+
+	reset();
 }
 
 ////////////////////////////////////////////////////////////////
