@@ -18,7 +18,7 @@ void _mouse_init_(){
 }
 
 char* fon[] = {
-"14 iso8859 * * * r *",
+"14 * 0 0 ",
 "16 iso8859 * * * r *",
 "18 iso8859 * * * r *",
 "20 iso8859 * * * r *",
